Module from_java

Module from_java 

Traits

FromJava
Specifies how a Java type should be converted before being fed to Rust.

Functions

from_java_static
Used in the generated code to have proper type bindings. You probably didn’t want to call this directly.