Module into_java
jni_
toolbox
0.2.2
Module into_
java
Module Items
Traits
In crate jni_
toolbox
jni_toolbox
Module
into_
java
Traits

Into
Java
Specifies how a Rust type should be converted into a Java primitive.
Into
Java
Object
Specifies how a Rust type should be converted into a Java object.